==> hguqiagenv3.db_2.2.5.tar.gz: hguqiagenv3.db/man/hguqiagenv3_dbconn.Rd <==
\name{hguqiagenv3_dbconn}

\alias{hguqiagenv3_dbconn}
\alias{hguqiagenv3_dbfile}
\alias{hguqiagenv3_dbschema}
\alias{hguqiagenv3_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hguqiagenv3_dbconn()
  hguqiagenv3_dbfile()
  hguqiagenv3_dbschema(file="", show.indices=FALSE)
  hguqiagenv3_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hguqiagenv3_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{hguqiagenv3_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{hguqiagenv3_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hguqiagenv3_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hguqiagenv3_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hguqiagenv3_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{hguqiagenv3_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hguqiagenv3_dbschema}: none (invisible \code{NULL}).

  \code{hguqiagenv3_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hguqiagenv3_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hguqiagenv3_dbconn() was created with:
  dbConnect(SQLite(), dbname=hguqiagenv3_dbfile(), cache_size=64000, synchronous=0)

  hguqiagenv3_dbschema()

  hguqiagenv3_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> hguqiagenv3.db_2.14.0.tar.gz: hguqiagenv3.db/man/hguqiagenv3_dbconn.Rd <==

\name{hguqiagenv3_dbconn}

\alias{hguqiagenv3_dbconn}
\alias{hguqiagenv3_dbfile}
\alias{hguqiagenv3_dbschema}
\alias{hguqiagenv3_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  hguqiagenv3_dbconn()
  hguqiagenv3_dbfile()
  hguqiagenv3_dbschema(file="", show.indices=FALSE)
  hguqiagenv3_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{hguqiagenv3_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{hguqiagenv3_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{hguqiagenv3_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{hguqiagenv3_dbschema} prints the schema definition of the
  package annotation DB.

  \code{hguqiagenv3_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{hguqiagenv3_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{hguqiagenv3_dbfile}: a character string with the path to the
  package annotation DB.

  \code{hguqiagenv3_dbschema}: none (invisible \code{NULL}).

  \code{hguqiagenv3_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(hguqiagenv3_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by hguqiagenv3_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=hguqiagenv3_dbfile(), cache_size=64000,
  synchronous=0)

  hguqiagenv3_dbschema()

  hguqiagenv3_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
